@@ -2,13 +2,14 @@ package Alien::Build::Interpolate::Default;
 
 use strict;
 use warnings;
+use 5.008004;
 use base qw( Alien::Build::Interpolate );
 use File::chdir;
 use File::Which qw( which );
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: Default interpolator for Alien::Build
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.29'; # VERSION
 
 sub _config
 {
@@ -249,7 +250,7 @@ Alien::Build::Interpolate::Default - Default interpolator for Alien::Build
 
 =head1 VERSION
 
-version 2.26
+version 2.29
 
 =head1 CONSTRUCTOR
 
@@ -461,6 +462,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
