@@ -2,10 +2,11 @@ package Test::Alien::CanCompile;
 
 use strict;
 use warnings;
+use 5.008004;
 use Test2::API qw( context );
 
 # ABSTRACT: Skip a test file unless a C compiler is available
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.29'; # VERSION
 
 
 sub skip
@@ -38,7 +39,7 @@ Test::Alien::CanCompile - Skip a test file unless a C compiler is available
 
 =head1 VERSION
 
-version 2.26
+version 2.29
 
 =head1 SYNOPSIS
 
@@ -115,6 +116,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
